Package: MSstats
Title: Protein Significance Analysis in DDA, SRM and DIA for Label-free
        or Label-based Proteomics Experiments
Version: 4.20.0
Date: 2025-03-05
Description: A set of tools for statistical relative protein
        significance analysis in DDA, SRM and DIA experiments.
Authors@R: c(
  person("Meena", "Choi", email = "mnchoi67@gmail.com", role = c("aut", "cre")),
  person("Mateusz", "Staniak", email = "mtst@mstaniak.pl", role = "aut"),
  person("Devon", "Kohler", email = "kohler.d@northeastern.edu", role = "aut"),
  person("Tony", "Wu", email = "wu.anthon@northeastern.edu", role = "aut"),
  person("Deril", "Raju", email = "raju.d@northeastern.edu", role = "aut"),
  person("Tsung-Heng", "Tsai", email = "tsai.tsungheng@gmail.com", role = "aut"), 
  person("Ting", "Huang", email = "thuang0703@gmail.com", role = "aut"),
  person("Olga", "Vitek", email = "o.vitek@northeastern.edu", role = "aut")) 
License: Artistic-2.0
Depends: R (>= 4.0)
Imports: MSstatsConvert, data.table, checkmate, MASS, htmltools, limma,
        lme4, preprocessCore, survival, utils, Rcpp, ggplot2 (>=
        3.4.0), ggrepel, gplots, plotly, marray, stats, grDevices,
        graphics, methods, statmod, parallel, rlang
Suggests: BiocStyle, knitr, rmarkdown, tinytest, covr, markdown,
        mockery, kableExtra
VignetteBuilder: knitr
biocViews: ImmunoOncology, MassSpectrometry, Proteomics, Software,
        Normalization, QualityControl, TimeCourse
LazyData: true
URL: http://msstats.org
BugReports: https://groups.google.com/forum/#!forum/msstats
RoxygenNote: 7.3.3
Encoding: UTF-8
NeedsCompilation: yes
Packaged: 2026-04-29 13:50:51 UTC; root
LinkingTo: Rcpp, RcppArmadillo
Config/pak/sysreqs: cmake make libicu-dev libuv1-dev libssl-dev
Repository: https://bioc-release.r-universe.dev
Date/Publication: 2026-04-28 12:38:18 UTC
RemoteUrl: https://github.com/bioc/MSstats
RemoteRef: RELEASE_3_23
RemoteSha: 87f0523a26249daa1a0543731ba44bbb9705b508
Author: Meena Choi [aut, cre],
  Mateusz Staniak [aut],
  Devon Kohler [aut],
  Tony Wu [aut],
  Deril Raju [aut],
  Tsung-Heng Tsai [aut],
  Ting Huang [aut],
  Olga Vitek [aut]
Maintainer: Meena Choi <mnchoi67@gmail.com>
Built: R 4.6.0; x86_64-apple-darwin20; 2026-04-29 13:59:59 UTC; unix
