# Generated by roxygen2: do not edit by hand

S3method(MSstatsContrastMatrix,character)
S3method(MSstatsContrastMatrix,data.frame)
S3method(MSstatsContrastMatrix,list)
S3method(MSstatsContrastMatrix,matrix)
export(DIANNtoMSstatsFormat)
export(DIAUmpiretoMSstatsFormat)
export(FragPipetoMSstatsFormat)
export(MSstatsContrastMatrix)
export(MSstatsGroupComparison)
export(MSstatsGroupComparisonOutput)
export(MSstatsGroupComparisonSingleProtein)
export(MSstatsHandleMissing)
export(MSstatsMergeFractions)
export(MSstatsNormalize)
export(MSstatsPrepareForDataProcess)
export(MSstatsPrepareForGroupComparison)
export(MSstatsPrepareForSummarization)
export(MSstatsQualityMetricsPlot)
export(MSstatsSelectFeatures)
export(MSstatsSummarizationOutput)
export(MSstatsSummarizeSingleLinear)
export(MSstatsSummarizeSingleTMP)
export(MSstatsSummarizeWithSingleCore)
export(MaxQtoMSstatsFormat)
export(OpenMStoMSstatsFormat)
export(OpenSWATHtoMSstatsFormat)
export(PDtoMSstatsFormat)
export(ProgenesistoMSstatsFormat)
export(SDRFtoAnnotation)
export(SkylinetoMSstatsFormat)
export(SpectronauttoMSstatsFormat)
export(checkRepeatedDesign)
export(dataProcess)
export(dataProcessPlots)
export(designSampleSize)
export(designSampleSizePlots)
export(extractSDRF)
export(getProcessed)
export(getSamplesInfo)
export(getSelectedProteins)
export(groupComparison)
export(groupComparisonPlots)
export(groupComparisonQCPlots)
export(makePeptidesDictionary)
export(modelBasedQCPlots)
export(quantification)
export(savePlot)
export(theme_msstats)
export(validateAnnotation)
import(data.table)
import(ggplot2)
import(limma)
import(lme4)
importFrom(MASS,rlm)
importFrom(MSstatsConvert,DIANNtoMSstatsFormat)
importFrom(MSstatsConvert,DIAUmpiretoMSstatsFormat)
importFrom(MSstatsConvert,FragPipetoMSstatsFormat)
importFrom(MSstatsConvert,MSstatsBalancedDesign)
importFrom(MSstatsConvert,MSstatsClean)
importFrom(MSstatsConvert,MSstatsImport)
importFrom(MSstatsConvert,MSstatsLogsSettings)
importFrom(MSstatsConvert,MSstatsMakeAnnotation)
importFrom(MSstatsConvert,MSstatsPreprocess)
importFrom(MSstatsConvert,MaxQtoMSstatsFormat)
importFrom(MSstatsConvert,OpenMStoMSstatsFormat)
importFrom(MSstatsConvert,OpenSWATHtoMSstatsFormat)
importFrom(MSstatsConvert,PDtoMSstatsFormat)
importFrom(MSstatsConvert,ProgenesistoMSstatsFormat)
importFrom(MSstatsConvert,SkylinetoMSstatsFormat)
importFrom(MSstatsConvert,SpectronauttoMSstatsFormat)
importFrom(Rcpp,sourceCpp)
importFrom(data.table,as.data.table)
importFrom(data.table,melt)
importFrom(data.table,rbindlist)
importFrom(data.table,setDT)
importFrom(data.table,uniqueN)
importFrom(ggrepel,geom_text_repel)
importFrom(gplots,heatmap.2)
importFrom(grDevices,dev.off)
importFrom(grDevices,hcl)
importFrom(grDevices,pdf)
importFrom(graphics,axis)
importFrom(graphics,image)
importFrom(graphics,legend)
importFrom(graphics,mtext)
importFrom(graphics,par)
importFrom(graphics,plot)
importFrom(graphics,plot.new)
importFrom(graphics,title)
importFrom(htmltools,div)
importFrom(htmltools,save_html)
importFrom(htmltools,tagList)
importFrom(limma,squeezeVar)
importFrom(lme4,lmer)
importFrom(marray,maPalette)
importFrom(methods,is)
importFrom(parallel,clusterExport)
importFrom(parallel,makeCluster)
importFrom(parallel,parLapply)
importFrom(parallel,stopCluster)
importFrom(plotly,add_trace)
importFrom(plotly,ggplotly)
importFrom(plotly,layout)
importFrom(plotly,plot_ly)
importFrom(plotly,style)
importFrom(plotly,subplot)
importFrom(preprocessCore,normalize.quantiles)
importFrom(rlang,.data)
importFrom(stats,dist)
importFrom(stats,fitted)
importFrom(stats,formula)
importFrom(stats,hclust)
importFrom(stats,lm)
importFrom(stats,loess)
importFrom(stats,median)
importFrom(stats,na.omit)
importFrom(stats,p.adjust)
importFrom(stats,predict)
importFrom(stats,qbinom)
importFrom(stats,qnorm)
importFrom(stats,qt)
importFrom(stats,quantile)
importFrom(stats,resid)
importFrom(stats,residuals)
importFrom(stats,sd)
importFrom(stats,vcov)
importFrom(stats,xtabs)
importFrom(survival,Surv)
importFrom(survival,survreg)
importFrom(utils,combn)
importFrom(utils,sessionInfo)
importFrom(utils,setTxtProgressBar)
importFrom(utils,txtProgressBar)
useDynLib(MSstats, .registration=TRUE)
