MSstats
=======

<!-- badges: start -->
  [![Travis build status](https://travis-ci.org/Vitek-Lab/MSstats-dev.svg?branch=master)](https://travis-ci.org/Vitek-Lab/MSstats-dev)
[![Codecov test coverage](https://codecov.io/gh/Vitek-Lab/MSstats-dev/branch/master/graph/badge.svg)](https://codecov.io/gh/Vitek-Lab/MSstats-dev?branch=master)
<!-- badges: end -->

MSstats is an R-based/Bioconductor package for statistical relative quantification of peptides and proteins in mass spectrometry-based proteomic experiments. It is applicable to multiple types of sample preparation, including label-free workflows, workflows that use stable isotope labeled reference proteins and peptides, and work-flows that use fractionation. It is applicable to targeted Selected Reactin Monitoring(SRM), Data-Dependent Acquisiton(DDA or shotgun), and Data-Independent Acquisition(DIA or SWATH-MS). This github page is for sharing source and testing. The official webpage is msstats.org
