# Generated by using Rcpp::compileAttributes() -> do not edit by hand
# Generator token: 10BE3573-1514-4C36-9D1C-5A225CD40393

get_estimable_fixed_random <- function(parameters, contrast) {
    .Call(`_MSstats_get_estimable_fixed_random`, parameters, contrast)
}

make_contrast_run_quant <- function(input, coefs, contrast_matrix, counts, is_labeled, is_reference = FALSE) {
    .Call(`_MSstats_make_contrast_run_quant`, input, coefs, contrast_matrix, counts, is_labeled, is_reference)
}

get_linear_summary <- function(input, coefs, counts, is_labeled, cov_mat) {
    .Call(`_MSstats_get_linear_summary`, input, coefs, counts, is_labeled, cov_mat)
}

median_polish_summary <- function(x, eps = 0.01, maxiter = 10L) {
    .Call(`_MSstats_median_polish_summary`, x, eps, maxiter)
}

