# For backwards compatibility, MSstats will export some converters in the 
# MSstats namespace

#' @export
#' @importFrom MSstatsConvert DIANNtoMSstatsFormat
MSstatsConvert::DIANNtoMSstatsFormat

#' @export
#' @importFrom MSstatsConvert DIAUmpiretoMSstatsFormat
MSstatsConvert::DIAUmpiretoMSstatsFormat

#' @export
#' @importFrom MSstatsConvert FragPipetoMSstatsFormat
MSstatsConvert::FragPipetoMSstatsFormat

#' @export
#' @importFrom MSstatsConvert MaxQtoMSstatsFormat
MSstatsConvert::MaxQtoMSstatsFormat

#' @export
#' @importFrom MSstatsConvert OpenMStoMSstatsFormat
MSstatsConvert::OpenMStoMSstatsFormat

#' @export
#' @importFrom MSstatsConvert OpenSWATHtoMSstatsFormat
MSstatsConvert::OpenSWATHtoMSstatsFormat

#' @export
#' @importFrom MSstatsConvert PDtoMSstatsFormat
MSstatsConvert::PDtoMSstatsFormat

#' @export
#' @importFrom MSstatsConvert ProgenesistoMSstatsFormat
MSstatsConvert::ProgenesistoMSstatsFormat

#' @export
#' @importFrom MSstatsConvert SkylinetoMSstatsFormat
MSstatsConvert::SkylinetoMSstatsFormat

#' @export
#' @importFrom MSstatsConvert SpectronauttoMSstatsFormat
MSstatsConvert::SpectronauttoMSstatsFormat