% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils_dataprocess_plots.R
\name{.getYaxis}
\alias{.getYaxis}
\title{Get name for y-axis}
\usage{
.getYaxis(temp)
}
\arguments{
\item{temp}{data.table}
}
\description{
Get name for y-axis
}
\keyword{internal}
