% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils_output.R
\name{.finalizeTMP}
\alias{.finalizeTMP}
\title{Summary statistics for output of TMP-based summarization}
\usage{
.finalizeTMP(input, censored_symbol, impute, summarized)
}
\arguments{
\item{input}{feature-level data}

\item{censored_symbol}{censored missing value indicator}

\item{impute}{if TRUE, censored missing values were imputed}

\item{summarized}{protein-level data (list)}
}
\description{
Summary statistics for output of TMP-based summarization
}
\keyword{internal}
