% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/msstats-package.R
\name{.onLoad}
\alias{.onLoad}
\title{Set default logging object when package is loaded}
\usage{
.onLoad(...)
}
\arguments{
\item{...}{ignored}
}
\value{
none, sets options called MSstatsLog and MSstatsMsg
}
\description{
Set default logging object when package is loaded
}
\keyword{internal}
